Index: src/Fragmentation/Automation/Controller/Commands/Operation.cpp
===================================================================
--- src/Fragmentation/Automation/Controller/Commands/Operation.cpp	(revision 41c1b778849fcd8e13f030bc1e1012ac80cd8881)
+++ src/Fragmentation/Automation/Controller/Commands/Operation.cpp	(revision 38032a2bcd60a9243123e7c23376316197727fc9)
@@ -29,5 +29,4 @@
 #include "CodePatterns/Info.hpp"
 #include "CodePatterns/Log.hpp"
-#include "types.hpp"
 
 #include "Controller/Commands/Operation.hpp"
Index: src/Fragmentation/Automation/Controller/Commands/SendJobToWorkerOperation.cpp
===================================================================
--- src/Fragmentation/Automation/Controller/Commands/SendJobToWorkerOperation.cpp	(revision 41c1b778849fcd8e13f030bc1e1012ac80cd8881)
+++ src/Fragmentation/Automation/Controller/Commands/SendJobToWorkerOperation.cpp	(revision 38032a2bcd60a9243123e7c23376316197727fc9)
@@ -28,5 +28,4 @@
 #include "CodePatterns/Info.hpp"
 #include "CodePatterns/Log.hpp"
-#include "types.hpp"
 
 #include "Controller/Commands/SendJobToWorkerOperation.hpp"
Index: src/Fragmentation/Automation/Controller/Commands/ShutdownOperation.cpp
===================================================================
--- src/Fragmentation/Automation/Controller/Commands/ShutdownOperation.cpp	(revision 41c1b778849fcd8e13f030bc1e1012ac80cd8881)
+++ src/Fragmentation/Automation/Controller/Commands/ShutdownOperation.cpp	(revision 38032a2bcd60a9243123e7c23376316197727fc9)
@@ -44,5 +44,5 @@
   {
     // Successfully established connection. Give choice.
-    enum ControllerChoices choice = Shutdown;
+    enum ControllerChoices choice = ShutdownControllerSocket;
     connection_.async_write(choice,
       boost::bind(&ShutdownOperation::handle_FinishOperation, this,
Index: src/Fragmentation/Automation/ControllerChoices.hpp
===================================================================
--- src/Fragmentation/Automation/ControllerChoices.hpp	(revision 41c1b778849fcd8e13f030bc1e1012ac80cd8881)
+++ src/Fragmentation/Automation/ControllerChoices.hpp	(revision 38032a2bcd60a9243123e7c23376316197727fc9)
@@ -2,5 +2,5 @@
  * ControllerChoices.hpp
  *
- *  Created on: Mar 2, 2012
+ *  Created on: Mar 1, 2012
  *      Author: heber
  */
@@ -9,5 +9,4 @@
 #define CONTROLLERCHOICES_HPP_
 
-
 // include config.h
 #ifdef HAVE_CONFIG_H
@@ -15,12 +14,12 @@
 #endif
 
-//!> Choices of the FragmentController in communication with FragmentScheduler
+//!> States the FragmentScheduler can be in to communicate with him
 enum ControllerChoices {
-  NoOperation,
+  NoControllerOperation,
   GetNextJobId,
   ReceiveJobs,
   CheckState,
   SendResults,
-  Shutdown
+  ShutdownControllerSocket
 };
 
Index: src/Fragmentation/Automation/FragmentScheduler.hpp
===================================================================
--- src/Fragmentation/Automation/FragmentScheduler.hpp	(revision 41c1b778849fcd8e13f030bc1e1012ac80cd8881)
+++ src/Fragmentation/Automation/FragmentScheduler.hpp	(revision 38032a2bcd60a9243123e7c23376316197727fc9)
@@ -107,5 +107,5 @@
       JobsQueue(_JobsQueue),
       jobInfo((size_t)2, 0),
-      choice(NoOperation),
+      choice(NoControllerOperation),
       globalId(0),
       initiateWorkerSocket(_initiateWorkerSocket)

Index: src/Fragmentation/Automation/FragmentScheduler.cpp
===================================================================
--- src/Fragmentation/Automation/FragmentScheduler.cpp	(revision 41c1b778849fcd8e13f030bc1e1012ac80cd8881)
+++ src/Fragmentation/Automation/FragmentScheduler.cpp	(revision 38032a2bcd60a9243123e7c23376316197727fc9)
@@ -248,5 +248,5 @@
     // switch over the desired choice read previously
     switch(choice) {
-    case NoOperation:
+    case NoControllerOperation:
     {
       ELOG(1, "FragmentScheduler::handle_ReadChoice() - called with NoOperation.");
@@ -294,5 +294,5 @@
       break;
     }
-    case Shutdown:
+    case ShutdownControllerSocket:
     {
       LaunchNewAcceptor = false;
@@ -304,6 +304,6 @@
       break;
     }
-    // restore NoOperation choice such that choice is not read twice
-    choice = NoOperation;
+    // restore NoControllerOperation choice such that choice is not read twice
+    choice = NoControllerOperation;
 
     if (LaunchNewAcceptor) {